import time
import argparse
import signal
import sys

from neopixel import *
from flask import Flask
app = Flask(__name__)

LED_COUNT = 120
LED_PIN = 18
LED_FREQ_HZ = 800000
LED_DMA = 5
LED_BRIGHTNESS = 255
LED_INVERT = False
LED_CHANNEL = 0
LED_STRIP = ws.WS2811_STRIP_GRB

neoColor = Color(255, 0, 0)

def signal_handler(signal, frame):
   ledOn(strip)
   sys.exit(0)

def opt_parse():
   parser = argparse.ArgumentParser()
   parser.add_argument('-c', action='store_true', help='clear the display on exit')
   args = parser.parse_args()
   if args.c:
      signal.signal(signal.SIGINT, signal_handler)

def ledOn(strip, color):
   for i in range(strip.numPixels()):
  	   strip.setPixelColor(i,color)
   strip.show()

def ledOff(strip):
   for i in range(strip.numPixels()):
      strip.setPixelColor(i,Color(0,0,0))
   strip.show()

def ledChangeColor(colorArr):
   neoColor = Color(colorArr[0],colorArr[1],colorArr[2])

strip = Adafruit_NeoPixel(LED_COUNT, LED_PIN, LED_FREQ_HZ, LED_DMA, LED_INVERT, LED_BRIGHTNESS, LED_CHANNEL, LED_STRIP)
opt_parse()
strip.begin()

@app.route("/")
def hello():
   return "Hello World"

@app.route("/ledOnOff/<onOff>")
def ledOnOff(onOff):
   if(onOff == "True"):
      ledOn(strip, neoColor)
      return "LED On"
   else:
      ledOff(strip) 
      return "LED Off"

@app.route("/ledColor/<r>/<g>/<b>")
def ledColor(r,g,b):
   r = int(r)
   g = int(g)
   b = int(b)
   color = Color(r, g, b)
   ledOn(strip, color)
   return "LED Changed Color"

if __name__ == "__main__":
   app.run(host='0.0.0.0', port=5000, debug=True)
